server.SimpleServer

|  | ## Cheshire3 Object Model: Class SimpleServer

Module server :: Class SimpleServer

## Class SimpleServer
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
           baseObjects.Server --+
                                |
                               SimpleServer

Instance Methods

__init__(self, session, configFile="serverConfig.xml") The constructer takes a Session object and a file path to the configuration file to be parsed and processed.
_cacheDatabases(self, session)
Inherited from `baseObjects.Server`: `authenticate`, `connect`, `disconnect` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

databases |
Inherited from `baseObjects.Server`: `authStore`, `queryStore`, `resultSetStore` Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, configFile="serverConfig.xml") (Constructor) | source code
The constructer takes a Session object and a file path to the configuration file to be parsed and processed. Overrides: baseObjects.Server.__init__ (inherited documentation)

### _cacheDatabases(self, session) | source code

Class Variable Details

    ### databases Value:
        {}